/****************************************************************************
 *
 * Copyright (c) 2011-2012, EBM WebSourcing
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA 
 *
 *****************************************************************************/
 
package javax.jbi.messaging;

import java.lang.reflect.Method;

import javax.jbi.ApiChecker;
import javax.jbi.servicedesc.ServiceEndpoint;
import javax.xml.namespace.QName;

import org.junit.Test;
import org.mockito.Mockito;

/**
 * @author Olivier Fabre - EBM WebSourcing
 */
public class DeliveryChannelTest extends ApiChecker {

    private MessageExchange mockMessageExchange = Mockito.mock(MessageExchange.class);

    DeliveryChannel mockDeliveryChannel = Mockito.mock(DeliveryChannel.class);

    public MessageExchange accept() throws MessagingException {
        return mockDeliveryChannel.accept();
    }

    @Test
    public void testAccept() throws MessagingException, IllegalArgumentException {
        @SuppressWarnings("unused")
        final long timeoutMS = 60000;
        MessageExchange messageExchange = mockDeliveryChannel.accept(timeoutMS);
    }

    @Test
    public void testAcceptThrowsMessagingExceptionAndIllegalArgumentException() {
        Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class,
                IllegalArgumentException.class };

        Method method = getTestedClassMethod("accept", long.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testClose() throws MessagingException {
        mockDeliveryChannel.close();
    }

    @Test
    public void testCloseThrowsMessagingException() {
        Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class };

        Method method = getTestedClassMethod("close");

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testCreateExchangeFactory() {
        @SuppressWarnings("unused")
        MessageExchangeFactory messageExchangeFactory = mockDeliveryChannel.createExchangeFactory();
    }

    @Test
    public void testCreateExchangeFactoryFromIntName() {
        @SuppressWarnings("unused")
        MessageExchangeFactory messageExchangeFactory = mockDeliveryChannel
                .createExchangeFactory(new QName("foo"));
    }

    @Test
    public void testCreateExchangeFactoryFromEp() {
        @SuppressWarnings("unused")
        MessageExchangeFactory messageExchangeFactory = mockDeliveryChannel
                .createExchangeFactory(Mockito.mock(ServiceEndpoint.class));
    }

    @Test
    public void testCreateExchangeFactoryForService() {
        @SuppressWarnings("unused")
        MessageExchangeFactory messageExchangeFactory = mockDeliveryChannel
                .createExchangeFactoryForService(new QName("foo"));
    }

    @Test
    public void testSend() throws MessagingException {
        mockDeliveryChannel.send(mockMessageExchange);
    }

    @Test
    public void testSendThrowsMessagingException() {
        Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class };

        Method method = getTestedClassMethod("send", MessageExchange.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testSendSync() throws MessagingException {
        @SuppressWarnings("unused")
        boolean b = mockDeliveryChannel.sendSync(mockMessageExchange);
    }

    @Test
    public void testSendSyncThrowsMessagingException() {
        Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class };

        Method method = getTestedClassMethod("sendSync", MessageExchange.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Test
    public void testSendSyncWithTimeout() throws MessagingException {
        @SuppressWarnings("unused")
        boolean b = mockDeliveryChannel.sendSync(mockMessageExchange, 1);
    }

    @Test
    public void testSendSyncWithTimeoutThrowsMessagingException() {
        Class<?>[] expectedExceptions = new Class<?>[] { MessagingException.class };

        Method method = getTestedClassMethod("sendSync", MessageExchange.class, long.class);

        checkMethodThrowsExpectedExceptions(method, expectedExceptions);
    }

    @Override
    protected Class<?> getTestedApiClass() {
        return DeliveryChannel.class;
    }

}
